==> kylin-scanner_3.2.0.6.tar.gz: kylin-scanner-3.2.0.6/src/toolbarwidget.h <==
#ifndef TOOLBARWIDGET_H
#define TOOLBARWIDGET_H

#include "globalsignal.h"
#include "svghandler.h"
#include "saneobject.h"

#include <ukui-log4qt.h>

#include <QWidget>
#include <QPushButton>
#include <QButtonGroup>
#include <QLabel>
#include <QFrame>
#include <QHBoxLayout>
#include <QPainter>
#include <QGraphicsDropShadowEffect>
#include <QFont>
#include <QPainter>
#include <QPaintEvent>
#include <QStyleOption>
#include <QColor>
#include <QIcon>
#include <QPixmap>

#define ToolBarWidgetColor QColor(249, 249, 249, 0.8*255)
#define ToolBarWidgetBlur 18
#define ToolBarWidgetFixedSize QSize(421, 36)
#define ToolBarWidgetButtonSize QSize(36, 36)
#define ToolBarWidgetFrameSize QSize(1, 16)
#define ToolBarWidgetZoomButtonSize QSize(20, 20)

class ToolBarWidget : public QWidget
{
    Q_OBJECT
public:
    explicit ToolBarWidget(QWidget *parent = nullptr);

    void setupGui();
    void initConnect();

    void themeChangedIconBlackSettings();
    void themeChangedIconWhiteSettings();

signals:

protected:
    void paintEvent(QPaintEvent *event) override;

    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
    void keyReleaseEvent(QKeyEvent *event) Q_DECL_OVERRIDE;


public slots:
    void themeChangedWhiteSlot();
    void themeChangedBlackSlot();

    void percentageChangedSlot();

    void beautyButtonClickedSlot();
    void rectifyButtonClickedSlot();
    void ocrButtonClickedSlot();
    void cropButtonClickedSlot();
    void rotateButtonClickedSlot();
    void mirrorButtonClickedSlot();
    void watermarkButtonClickedSlot();
    void zoomoutButtonClickedSlot();
    void zoominButtonClickedSlot();
    void themeChangedSlot();

private:

    QPushButton *m_beautyButton;
    QPushButton *m_rectifyButton;
    QPushButton *m_ocrButton;

    QFrame *m_leftFrame;

    QPushButton *m_cropButton;
    QPushButton *m_rotateButton;
    QPushButton *m_mirrorButton;
    QPushButton *m_watermarkButton;

    QFrame *m_rightFrame;

    QPushButton *m_zoomOutButton; // Make small
    QLabel *m_percentageLabel;
    QPushButton *m_zoomInButton; // Make large

    QHBoxLayout *m_mainHLayout;
};

#endif // TOOLBARWIDGET_H

==> kylin-scanner_3.2.1.orig.tar.gz: kylin-scanner-3.2.1/src/toolbarwidget.h <==
#ifndef TOOLBARWIDGET_H
#define TOOLBARWIDGET_H

#include "globalsignal.h"
#include "svghandler.h"
#include "saneobject.h"

#include <ukui-log4qt.h>

#include <QWidget>
#include <QPushButton>
#include <QButtonGroup>
#include <QLabel>
#include <QFrame>
#include <QHBoxLayout>
#include <QPainter>
#include <QGraphicsDropShadowEffect>
#include <QFont>
#include <QPainter>
#include <QPaintEvent>
#include <QStyleOption>
#include <QColor>
#include <QIcon>
#include <QPixmap>
#include <kborderlessbutton.h>
#include "runningdialog.h"
#include "utils/HorizontalOrVerticalMode.h"
#define ToolBarWidgetColor QColor(249, 249, 249, 0.8*255)
#define ToolBarWidgetBlur 18
#define ToolBarWidgetFixedSize QSize(421, 36)
#define ToolBarWidgetTableModeSize QSize(522, 64)
#define ToolBarWidgetButtonSize QSize(36, 36)
#define ToolBarWidgetTableModeButtonSize QSize(48, 48)
#define ToolBarWidgetFrameSize QSize(1, 16)
#define ToolBarWidgetZoomButtonSize QSize(20, 20)
#define ToolBarWidgetTableModeZoomButtonSize QSize(36, 36)

class ToolBarWidget : public QWidget
{
    Q_OBJECT
public:
    explicit ToolBarWidget(QWidget *parent = nullptr);

    void setupGui();
    void initConnect();

    void themeChangedIconBlackSettings();
    void themeChangedIconWhiteSettings();
    void ocrOtherIconState(bool flag);
signals:

protected:
    void paintEvent(QPaintEvent *event) override;

    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
    void keyReleaseEvent(QKeyEvent *event) Q_DECL_OVERRIDE;


public slots:
    void themeChangedWhiteSlot();
    void themeChangedBlackSlot();

    void percentageChangedSlot();

    void beautyButtonClickedSlot();
    void rectifyButtonClickedSlot();
    void ocrButtonClickedSlot();
    void cropButtonClickedSlot();
    void rotateButtonClickedSlot();
    void mirrorButtonClickedSlot();
    void watermarkButtonClickedSlot();
    void zoomoutButtonClickedSlot();
    void zoominButtonClickedSlot();
    void themeChangedSlot();
    void rotateChangedSlot(bool isPCMode);

private:

    kdk::KBorderlessButton *m_beautyButton;
    kdk::KBorderlessButton *m_rectifyButton;
    kdk::KBorderlessButton *m_ocrButton;

    QFrame *m_leftFrame;

    kdk::KBorderlessButton *m_cropButton;
    kdk::KBorderlessButton *m_rotateButton;
    kdk::KBorderlessButton *m_mirrorButton;
    kdk::KBorderlessButton *m_watermarkButton;

    QFrame *m_rightFrame;

    kdk::KBorderlessButton *m_zoomOutButton; // Make small
    QLabel *m_percentageLabel;
    kdk::KBorderlessButton *m_zoomInButton; // Make large

    QHBoxLayout *m_mainHLayout;
    RunningDialog *beautyRunningDialog = nullptr;
    HorizontalOrVerticalMode m_mode;

    void drawFrame();
};

#endif // TOOLBARWIDGET_H
